==> haskell-hxt-charproperties-9.2.0.1-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-charproperties
version: 9.2.0.1
id: hxt-charproperties-9.2.0.1-L1rhanzXQ304SfBOSkeXkX
key: hxt-charproperties-9.2.0.1-L1rhanzXQ304SfBOSkeXkX
license: MIT
copyright: Copyright (c) 2010-2014 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Character properties and classes for XML and Unicode
description:
    Character proprties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 7.0.0
category: Text
author: Uwe Schmidt
exposed: True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet
abi: b344205757cbe00fc437f23a11aac969
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-charproperties-9.2.0.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-charproperties-9.2.0.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/hxt-charproperties-9.2.0.1
hs-libraries: HShxt-charproperties-9.2.0.1-L1rhanzXQ304SfBOSkeXkX
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock
haddock-html: /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-charproperties-9.2.0.1-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-charproperties.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-charproperties
version: 9.2.0.1
id: hxt-charproperties-9.2.0.1-48OogeCJMUc1lcYcm9OQtr
key: hxt-charproperties-9.2.0.1-48OogeCJMUc1lcYcm9OQtr
license: MIT
copyright: Copyright (c) 2010-2014 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: Character properties and classes for XML and Unicode
description:
    Character proprties defined by XML and Unicode standards.
    These modules contain predicates for Unicode blocks and char proprties
    and character predicates defined by XML.
    Supported Unicode version is 7.0.0
category: Text
author: Uwe Schmidt
exposed: True
exposed-modules:
    Data.Char.Properties.UnicodeBlocks
    Data.Char.Properties.UnicodeCharProps
    Data.Char.Properties.XMLCharProps Data.Set.CharSet
abi: 10c8f2fa6e21b999d6f8556bfab65251
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hxt-charproperties-9.2.0.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/hxt-charproperties-9.2.0.1
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/hxt-charproperties-9.2.0.1
hs-libraries: HShxt-charproperties-9.2.0.1-48OogeCJMUc1lcYcm9OQtr
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-hxt-charproperties/html/hxt-charproperties.haddock
haddock-html: /usr/share/doc/haskell-hxt-charproperties/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
